.. image:: https://github.com/zopefoundation/DateTime/workflows/tests/badge.svg
        :target: https://github.com/zopefoundation/DateTime/actions?query=workflow%3Atests
        :alt: CI status

.. image:: https://img.shields.io/pypi/v/DateTime.svg
        :target: https://pypi.org/project/DateTime/
        :alt: Current version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/DateTime.svg
        :target: https://pypi.org/project/DateTime/
        :alt: Supported Python versions


DateTime
========

This package provides a DateTime data type, as known from Zope.

Unless you need to communicate with Zope APIs, you're probably better
off using Python's built-in datetime module.

For further documentation, please have a look at `src/DateTime/DateTime.txt`.
